#!perl

BEGIN {
  unless ( $ENV{ RELEASE_TESTING } ) {
    require Test::More;
    Test::More::plan( skip_all => 'these tests are for release candidate testing' );
  }
}

use Test::More;

eval "use Test::HasVersion";
plan skip_all => "Test::HasVersion required for testing version numbers"
  if $@;
all_pm_version_ok();
